[gnome-sound-recorder/zbrown/gitlab-what-now: 3/4] record: Change file naming format



commit 72c2ec165d6d619f7e0b88e6e6df6bdeed4bf949
Author: Saad Patel <patelsaadn gmail com>
Date:   Wed Feb 26 20:56:38 2020 +0530

    record: Change file naming format

 src/record.js | 9 ++++-----
 1 file changed, 4 insertions(+), 5 deletions(-)
---
diff --git a/src/record.js b/src/record.js
index 00405c5..5a8e492 100644
--- a/src/record.js
+++ b/src/record.js
@@ -350,11 +350,10 @@ const BuildFileName = class BuildFileName {
         var fileExtensionName = MainWindow.audioProfile.fileExtensionReturner();
         var dir = Gio.Application.get_default().saveDir;
         this.dateTime = GLib.DateTime.new_now_local();
-        var clipNumber = Listview.trackNumber + 1;
-        /* Translators: ""Clip %d"" is the default name assigned to a file created
-            by the application (for example, "Clip 1"). */
-        var clipName = _("Clip %d").format(clipNumber.toString());
-        this.clip = dir.get_child_for_display_name(clipName);
+        /* Translators: ""Recording from %R on %A %F "" is the default name assigned to a file created
+            by the application (for example, "Recording from 14:40:30 on Tuesday 2020-02-25"). */
+        var clipName = this.dateTime.format (_("Recording from %R on %A %F"));        
+        this.clip = dir.get_child_for_display_name(clipName); 
         var file = this.clip.get_path();
         return file;
     }


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]